A image processing pipeline to automatically crop and quantify tumor burdens (radiance) in mice treated with bioluminescent tumors.   
Intutitive processing of quantitative radiance data and raw mouse images is supported through a user friendly GUI interface.
 
To use this package:
1. If anaconda is not installed, follow installation instructions here: https://docs.anaconda.com/anaconda/install/
2. Start terminal, type in and enter:
```
conda activate
```
3. Now install radianceQuantifier via PyPi by typing the following line in the terminal:
```
pip install radiance-quantifier
```
4. In this anaconda environment, type: 
```
python3 -m radiance-quantifier
```
to start the program
